==> coupon-facade-1.0.0-zds-20220401.062950-16-sources.jar: com/bizvane/couponfacade/models/vo/CouponSendLogVo.java <==
package com.bizvane.couponfacade.models.vo;

import io.swagger.annotations.ApiModelProperty;
import lombok.Data;

import java.io.Serializable;
import java.math.BigDecimal;
import java.util.Date;

/**
 * @author zcc
 * @date 2022/3/25 18:44
 **/

@Data
public class CouponSendLogVo implements Serializable {
    private static final long serialVersionUID = -6538478817130498044L;

    @ApiModelProperty(value = "主键", name = "couponSendLogId", required = false,example = "")
    private Long couponSendLogId;

    @ApiModelProperty(value = "企业id", name = "sysCompanyId", required = false,example = "")
    private Long sysCompanyId;

    @ApiModelProperty(value = "品牌id", name = "sysBrandId", required = false,example = "")
    private Long sysBrandId;

    @ApiModelProperty(value = "couponCode", name = "couponCode", required = false,example = "")
    private String couponCode;

    @ApiModelProperty(value = "线下券定义code", name = "erpCouponDefinitionCode", required = false,example = "")
    private String erpCouponDefinitionCode;

    @ApiModelProperty(value = "memberCode", name = "memberCode", required = false,example = "")
    private String memberCode;

    @ApiModelProperty(value = "erpId", name = "erpId", required = false,example = "")
    private String erpId;

    @ApiModelProperty(value = "券名称", name = "couponName", required = false,example = "")
    private String couponName;

    @ApiModelProperty(value = "类型", name = "preferentialType", required = false,example = "")
    private Byte preferentialType;

    @ApiModelProperty(value = "金额", name = "money", required = false,example = "")
    private BigDecimal money;

    @ApiModelProperty(value = "折扣", name = "discount", required = false,example = "")
    private BigDecimal discount;

    @ApiModelProperty(value = "发送类型 CouponSendTypeEnum.class枚举", name = "sendType", required = false,example = "")
    private String sendType;

    @ApiModelProperty(value = "业务名称", name = "businessName", required = false,example = "")
    private String businessName;

    @ApiModelProperty(value = "发送状态 CouponSendStatusEnum.class枚举", name = "sendStatus", required = false,example = "")
    private Integer sendStatus;

    @ApiModelProperty(value = "发送时间", name = "sendDate", required = false,example = "")
    private Date sendDate;

    @ApiModelProperty(value = "发送结果信息", name = "sendFlagInfo", required = false,example = "")
    private String sendFlagInfo;

    @ApiModelProperty(value = "发送员工code", name = "sendStaffCode", required = false,example = "")
    private String sendStaffCode;

    @ApiModelProperty(value = "会员卡号", name = "cardNo", required = false,example = "")
    private String cardNo;

    @ApiModelProperty(value = "会员备注", name = "memberComment", required = false,example = "")
    private String memberComment;

    @ApiModelProperty(value = "会员名称", name = "memberName", required = false,example = "")
    private String memberName;

    @ApiModelProperty(value = "会员头像", name = "headPortraits", required = false,example = "")
    private String headPortraits;
}

==> coupon-facade-1.0.1-zds-20220725.024647-3-sources.jar: com/bizvane/couponfacade/models/vo/CouponSendLogVo.java <==
package com.bizvane.couponfacade.models.vo;

import io.swagger.annotations.ApiModelProperty;
import lombok.Data;

import java.io.Serializable;
import java.math.BigDecimal;
import java.util.Date;

/**
 * @author zcc
 * @date 2022/3/25 18:44
 **/

@Data
public class CouponSendLogVo implements Serializable {
    private static final long serialVersionUID = -6538478817130498044L;

    @ApiModelProperty(value = "主键", name = "couponSendLogId", required = false,example = "")
    private Long couponSendLogId;

    @ApiModelProperty(value = "企业id", name = "sysCompanyId", required = false,example = "")
    private Long sysCompanyId;

    @ApiModelProperty(value = "品牌id", name = "sysBrandId", required = false,example = "")
    private Long sysBrandId;

    @ApiModelProperty(value = "couponCode", name = "couponCode", required = false,example = "")
    private String couponCode;

    @ApiModelProperty(value = "线下券定义code", name = "erpCouponDefinitionCode", required = false,example = "")
    private String erpCouponDefinitionCode;

    @ApiModelProperty(value = "memberCode", name = "memberCode", required = false,example = "")
    private String memberCode;

    @ApiModelProperty(value = "erpId", name = "erpId", required = false,example = "")
    private String erpId;

    @ApiModelProperty(value = "券名称", name = "couponName", required = false,example = "")
    private String couponName;

    @ApiModelProperty(value = "类型", name = "preferentialType", required = false,example = "")
    private Byte preferentialType;

    @ApiModelProperty(value = "金额", name = "money", required = false,example = "")
    private BigDecimal money;

    @ApiModelProperty(value = "折扣", name = "discount", required = false,example = "")
    private BigDecimal discount;

    @ApiModelProperty(value = "发送类型 CouponSendTypeEnum.class枚举", name = "sendType", required = false,example = "")
    private String sendType;

    @ApiModelProperty(value = "业务名称", name = "businessName", required = false,example = "")
    private String businessName;

    @ApiModelProperty(value = "发送状态 CouponSendStatusEnum.class枚举", name = "sendStatus", required = false,example = "")
    private Integer sendStatus;

    @ApiModelProperty(value = "发送时间", name = "sendDate", required = false,example = "")
    private Date sendDate;

    @ApiModelProperty(value = "发送结果信息", name = "sendFlagInfo", required = false,example = "")
    private String sendFlagInfo;

    @ApiModelProperty(value = "发送员工code", name = "sendStaffCode", required = false,example = "")
    private String sendStaffCode;

    @ApiModelProperty(value = "会员卡号", name = "cardNo", required = false,example = "")
    private String cardNo;

    @ApiModelProperty(value = "会员备注", name = "memberComment", required = false,example = "")
    private String memberComment;

    @ApiModelProperty(value = "会员名称", name = "memberName", required = false,example = "")
    private String name;

    @ApiModelProperty(value = "会员头像", name = "headPortraits", required = false,example = "")
    private String headPortraits;
}
